@@ -1,5 +1,5 @@
 /*!
- * froala_editor v1.2.3 (http://editor.froala.com)
+ * froala_editor v1.2.4 (http://editor.froala.com)
  * Copyright 2014-2014 Froala
  */
 
@@ -83,7 +83,11 @@ $.Editable.LANGS['cs'] = {
     "Delete row": "Smazat \u0159\u00e1dek",
     "Insert column before": "Vlo\u017eit sloupec vlevo",
     "Insert column after": "Vlo\u017eit sloupec vpravo",
-    "Delete column": "Smazat sloupec"
+    "Delete column": "Smazat sloupec",
+    "Uploading image": "Nahr\u00e1v\u00e1n\u00ed obrazu",
+    "Upload File": "Nahr\u00e1t soubor",
+    "Drop File": "Drop soubor",
+    "Clear formatting": "Vymazat form\u00e1tov\u00e1n\u00ed"
   },
   direction: "ltr"
 };
