@@ -1,5 +1,5 @@
 /*!
- * froala_editor v1.2.1 (http://editor.froala.com)
+ * froala_editor v1.2.4 (http://editor.froala.com)
  * Copyright 2014-2014 Froala
  */
 
@@ -15,8 +15,8 @@ $.Editable.LANGS['he'] = {
     "Strikethrough": "\u05e7\u05d5 \u05d0\u05de\u05e6\u05e2\u05d9",
     "Font Size": "\u05d2\u05d5\u05d3\u05dc \u05d4\u05d2\u05d5\u05e4\u05df",
     "Color": "\u05e6\u05d1\u05e2",
-    "Background Color": "\u05e6\u05d1\u05e2 \u05e8\u05e7\u05e2",
-    "Text Color": "\u05e6\u05d1\u05e2 \u05d4\u05d8\u05e1\u05d8",
+    "Background": "\u05e8\u05e7\u05e2",
+    "Text": "\u05d4\u05d8\u05e1\u05d8",
     "Format Block": "\u05e4\u05d5\u05e8\u05de\u05d8",
     "Normal": "\u05e8\u05d2\u05d9\u05dc",
     "Paragraph": "\u05e4\u05e1\u05e7\u05d4",
@@ -83,7 +83,11 @@ $.Editable.LANGS['he'] = {
     "Delete row": "\u05de\u05d7\u05d9\u05e7\u05ea \u05e9\u05d5\u05e8\u05d4",
     "Insert column before": "\u05d4\u05d5\u05e1\u05e4\u05ea \u05d8\u05d5\u05e8 \u05dc\u05e4\u05e0\u05d9",
     "Insert column after": "\u05d4\u05d5\u05e1\u05e4\u05ea \u05d8\u05d5\u05e8 \u05d0\u05d7\u05e8\u05d9",
-    "Delete column": "\u05de\u05d7\u05d9\u05e7\u05ea \u05d8\u05d5\u05e8"
+    "Delete column": "\u05de\u05d7\u05d9\u05e7\u05ea \u05d8\u05d5\u05e8",
+    "Uploading image": "\u05ea\u05de\u05d5\u05e0\u05ea \u05d4\u05e2\u05dc\u05d0\u05d4",
+    "Upload File": "\u05d4\u05e2\u05dc\u05d0\u05ea \u05e7\u05d5\u05d1\u05e5",
+    "Drop File": "\u05d6\u05e8\u05d5\u05e7 \u05e7\u05d5\u05d1\u05e5 \u05db\u05d0\u05df",
+    "Clear formatting": "\u05dc\u05d4\u05e1\u05d9\u05e8 \u05e2\u05d9\u05e6\u05d5\u05d1"
   },
   direction: "rtl"
 };
