@@ -1,5 +1,5 @@
 /*!
- * froala_editor v1.2.1 (http://editor.froala.com)
+ * froala_editor v1.2.4 (http://editor.froala.com)
  * Copyright 2014-2014 Froala
  */
 
@@ -9,16 +9,16 @@
 
 $.Editable.LANGS['ru'] = {
   translation: {
-    "Bold": "\u041f\u043e\u043b\u0443\u0436\u0438\u0440\u043d\u044b\u0439",
+    "Bold": "\u0416\u0438\u0440\u043d\u044b\u0439",
     "Italic": "\u041a\u0443\u0440\u0441\u0438\u0432",
     "Underline": "\u041f\u043e\u0434\u0447\u0435\u0440\u043a\u043d\u0443\u0442\u044b\u0439",
     "Strikethrough": "\u0417\u0430\u0447\u0435\u0440\u043a\u043d\u0443\u0442\u044b\u0439",
     "Font Size": "\u0420\u0430\u0437\u043c\u0435\u0440 \u0448\u0440\u0438\u0444\u0442\u0430",
     "Color": "\u0426\u0432\u0435\u0442",
-    "Background Color": "\u0426\u0432\u0435\u0442 \u0444\u043e\u043d\u0430",
-    "Text Color": "\u0426\u0432\u0435\u0442 \u0442\u0435\u043a\u0441\u0442\u0430",
+    "Background": "\u0424\u043e\u043d",
+    "Text": "\u0442\u0435\u043a\u0441\u0442",
     "Format Block": "\u0424\u043e\u0440\u043c\u0430\u0442",
-    "Normal": "\u043d\u043e\u0440\u043c\u0430\u043b\u044c\u043d\u044b\u0439",
+    "Normal": "\u041d\u043e\u0440\u043c\u0430\u043b\u044c\u043d\u044b\u0439",
     "Paragraph": "\u041f\u0430\u0440\u0430\u0433\u0440\u0430\u0444",
     "Code": "\u041a\u043e\u0434",
     "Quote": "\u0426\u0438\u0442\u0430\u0442\u0430",
@@ -28,7 +28,7 @@ $.Editable.LANGS['ru'] = {
     "Heading 4": "\u0417\u0430\u0433\u043e\u043b\u043e\u0432\u043e\u043a 4",
     "Heading 5": "\u0417\u0430\u0433\u043e\u043b\u043e\u0432\u043e\u043a 5",
     "Heading 6": "\u0417\u0430\u0433\u043e\u043b\u043e\u0432\u043e\u043a 6",
-    "Block Style": "\u0411\u043b\u043e\u043a \u0441\u0442\u0438\u043b\u044c",
+    "Block Style": "\u0421\u0442\u0438\u043b\u044c \u0431\u043b\u043e\u043a\u0430",
     "Alignment": "\u0412\u044b\u0440\u0430\u0432\u043d\u0438\u0432\u0430\u043d\u0438\u0435",
     "Align Left": "\u041f\u043e \u043b\u0435\u0432\u043e\u043c\u0443 \u043a\u0440\u0430\u044e",
     "Align Center": "\u041f\u043e \u0446\u0435\u043d\u0442\u0440\u0443",
@@ -38,53 +38,56 @@ $.Editable.LANGS['ru'] = {
     "Bulleted List": "\u041c\u0430\u0440\u043a\u0438\u0440\u043e\u0432\u0430\u043d\u043d\u044b\u0439 \u0441\u043f\u0438\u0441\u043e\u043a",
     "Indent Less": "\u0423\u043c\u0435\u043d\u044c\u0448\u0438\u0442\u044c \u043e\u0442\u0441\u0442\u0443\u043f",
     "Indent More": "\u0423\u0432\u0435\u043b\u0438\u0447\u0438\u0442\u044c \u043e\u0442\u0441\u0442\u0443\u043f",
-    "Select All": "\u0412\u044b\u0434\u0435\u043b\u0438\u0442\u044c \u0432\u0441\u0435",
+    "Select All": "\u0412\u044b\u0431\u0440\u0430\u0442\u044c \u0432\u0441\u0435",
     "Insert Link": "\u0412\u0441\u0442\u0430\u0432\u0438\u0442\u044c \u0441\u0441\u044b\u043b\u043a\u0443",
     "Insert Image": "\u0412\u0441\u0442\u0430\u0432\u0438\u0442\u044c \u0438\u0437\u043e\u0431\u0440\u0430\u0436\u0435\u043d\u0438\u0435",
     "Insert Video": "\u0412\u0441\u0442\u0430\u0432\u0438\u0442\u044c \u0432\u0438\u0434\u0435\u043e",
     "Undo": "\u0412\u0435\u0440\u043d\u0443\u0442\u044c",
-    "Redo": "\u041e\u0442\u043c\u0435\u043d\u0438\u0442\u044c",
+    "Redo": "\u041f\u043e\u0432\u0442\u043e\u0440\u0438\u0442\u044c",
     "Show HTML": "\u041f\u043e\u043a\u0430\u0437\u0430\u0442\u044c HTML",
-    "Float Left": "\u041f\u043e \u043b\u0435\u0432\u043e\u043c\u0443 \u043a\u0440\u0430\u044e",
-    "Float None": "\u041d\u0435\u0442",
-    "Float Right": "\u041f\u043e \u043f\u0440\u0430\u0432\u043e\u043c\u0443 \u043a\u0440\u0430\u044e",
+    "Float Left": "\u041e\u0431\u0442\u0435\u043a\u0430\u043d\u0438\u0435 \u0441\u043f\u0440\u0430\u0432\u0430",
+    "Float None": "\u041d\u0435\u0442 \u043e\u0431\u0442\u0435\u043a\u0430\u043d\u0438\u044f",
+    "Float Right": "\u041e\u0431\u0442\u0435\u043a\u0430\u043d\u0438\u0435 \u0441\u043b\u0435\u0432\u0430",
     "Replace Image": "\u0417\u0430\u043c\u0435\u043d\u0438\u0442\u044c \u0438\u0437\u043e\u0431\u0440\u0430\u0436\u0435\u043d\u0438\u0435",
     "Remove Image": "\u0423\u0434\u0430\u043b\u0438\u0442\u044c \u0438\u0437\u043e\u0431\u0440\u0430\u0436\u0435\u043d\u0438\u0435",
-    "Title": "\u0417\u0430\u0433\u043e\u043b\u043e\u0432\u043e\u043a",
-    "Insert image": "\u0412\u0441\u0442\u0430\u0432\u0438\u0442\u044c \u0438\u0437\u043e\u0431\u0440\u0430\u0436\u0435\u043d\u0438\u0435",
-    "Drop image": "\u0411\u0440\u043e\u0441\u044c\u0442\u0435 \u0438\u0437\u043e\u0431\u0440\u0430\u0436\u0435\u043d\u0438\u0435",
+    "Title": "\u041d\u0430\u0437\u0432\u0430\u043d\u0438\u0435",
+    "Drop image": "\u041f\u0435\u0440\u0435\u043c\u0435\u0441\u0442\u0438\u0442\u0435 \u0441\u044e\u0434\u0430 \u0444\u0430\u0439\u043b",
     "or click": "\u0438\u043b\u0438 \u043d\u0430\u0436\u043c\u0438\u0442\u0435",
     "or": "\u0438\u043b\u0438",
     "Enter URL": "\u0412\u0432\u0435\u0434\u0438\u0442\u0435 URL",
-    "Please wait!": "\u041f\u043e\u0436\u0430\u043b\u0443\u0439\u0441\u0442\u0430, \u043f\u043e\u0434\u043e\u0436\u0434\u0438\u0442\u0435!",
+    "Please wait!": "\u041f\u043e\u0436\u0430\u043b\u0443\u0439\u0441\u0442\u0430 \u043f\u043e\u0434\u043e\u0436\u0434\u0438\u0442\u0435!",
     "Are you sure? Image will be deleted.": "\u0412\u044b \u0443\u0432\u0435\u0440\u0435\u043d\u044b? \u0418\u0437\u043e\u0431\u0440\u0430\u0436\u0435\u043d\u0438\u0435 \u0431\u0443\u0434\u0435\u0442 \u0443\u0434\u0430\u043b\u0435\u043d\u043e.",
     "UNLINK": "\u0423\u0434\u0430\u043b\u0438\u0442\u044c \u0441\u0441\u044b\u043b\u043a\u0443",
-    "Open in new tab": "\u041e\u0442\u043a\u0440\u044b\u0442\u044c \u0432 \u043d\u043e\u0432\u043e\u0439 \u0432\u043a\u043b\u0430\u0434\u043a\u0435",
-    "Type something": "\u0412\u0432\u0435\u0434\u0438\u0442\u0435 \u0447\u0442\u043e\u002d\u043d\u0438\u0431\u0443\u0434\u044c",
+    "Open in new tab": "\u041e\u0442\u043a\u0440\u044b\u0442\u044c \u0432 \u043d\u043e\u0432\u043e\u0439 \u0432\u043a\u043b\u0430\u0434\u043a",
+    "Type something": "\u041d\u0430\u043f\u0438\u0448\u0438\u0442\u0435 \u0447\u0442\u043e\u002d\u043d\u0438\u0431\u0443\u0434\u044c",
     "Cancel": "\u041e\u0442\u043c\u0435\u043d\u0438\u0442\u044c",
-    "OK": "\u041e\u043a",
-    "Manage images": "\u0434\u043b\u044f \u0440\u0430\u0431\u043e\u0442\u044b \u0441 \u0438\u0437\u043e\u0431\u0440\u0430\u0436\u0435\u043d\u0438\u044f\u043c\u0438",
-    "Delete": "\u0443\u0434\u0430\u043b\u044f\u0442\u044c",
+    "OK": "OK",
+    "Manage images": "\u0423\u043f\u0440\u0430\u0432\u043b\u0435\u043d\u0438\u0435 \u0438\u0437\u043e\u0431\u0440\u0430\u0436\u0435\u043d\u0438\u044f\u043c\u0438",
+    "Delete": "\u0423\u0434\u0430\u043b\u0438\u0442\u044c",
     "Font Family": "\u0428\u0440\u0438\u0444\u0442",
-    "Insert Horizontal Line": "\u0412\u0441\u0442\u0430\u0432\u044c\u0442\u0435 \u0433\u043e\u0440\u0438\u0437\u043e\u043d\u0442\u0430\u043b\u044c\u043d\u0443\u044e \u043b\u0438\u043d\u0438\u044e",
+    "Insert Horizontal Line": "\u0412\u0441\u0442\u0430\u0432\u0438\u0442\u044c \u0433\u043e\u0440\u0438\u0437\u043e\u043d\u0442\u0430\u043b\u044c\u043d\u0443\u044e \u043b\u0438\u043d\u0438\u044e",
     "Table": "\u0422\u0430\u0431\u043b\u0438\u0446\u0430",
-    "Insert table": "\u0422\u0438\u043f \u0441\u0442\u0440\u043e\u043a\u0438",
+    "Insert table": "\u0412\u0441\u0442\u0430\u0432\u0438\u0442\u044c \u0442\u0430\u0431\u043b\u0438\u0446\u0443",
     "Cell": "\u042f\u0447\u0435\u0439\u043a\u0430",
     "Row": "\u0421\u0442\u0440\u043e\u043a\u0430",
     "Column": "\u0421\u0442\u043e\u043b\u0431\u0435\u0446",
     "Delete table": "\u0423\u0434\u0430\u043b\u0438\u0442\u044c \u0442\u0430\u0431\u043b\u0438\u0446\u0443",
-    "Insert cell before": "\u0412\u0441\u0442\u0430\u0432\u044c\u0442\u0435 \u044f\u0447\u0435\u0439\u043a\u0443 \u0434\u043e",
-    "Insert cell after": "\u0412\u0441\u0442\u0430\u0432\u044c\u0442\u0435 \u044f\u0447\u0435\u0439\u043a\u0443 \u043f\u043e\u0441\u043b\u0435",
+    "Insert cell before": "\u0412\u0441\u0442\u0430\u0432\u0438\u0442\u044c \u044f\u0447\u0435\u0439\u043a\u0443 \u0434\u043e",
+    "Insert cell after": "\u0412\u0441\u0442\u0430\u0432\u0438\u0442\u044c \u044f\u0447\u0435\u0439\u043a\u0443 \u043f\u043e\u0441\u043b\u0435",
     "Delete cell": "\u0423\u0434\u0430\u043b\u0438\u0442\u044c \u044f\u0447\u0435\u0439\u043a\u0443",
-    "Merge cells": "\u041e\u0431\u044a\u0435\u0434\u0438\u043d\u0438\u0442\u044c \u044f\u0447\u0435\u0439\u043a\u0438",
-    "Horizontal split": "\u0413\u043e\u0440\u0438\u0437\u043e\u043d\u0442\u0430\u043b\u044c\u043d\u043e\u0435 \u0440\u0430\u0437\u0434\u0435\u043b\u0435\u043d\u0438\u0435",
-    "Vertical split": "\u0412\u0435\u0440\u0442\u0438\u043a\u0430\u043b\u044c\u043d\u044b\u0439 \u0440\u0430\u0441\u043a\u043e\u043b",
+    "Merge cells": "\u041e\u0431\u044a\u0435\u0434\u0435\u043d\u0438\u0442\u044c \u044f\u0447\u0435\u0439\u043a\u0438",
+    "Horizontal split": "\u0420\u0430\u0437\u0434\u0435\u043b\u0438\u0442\u044c \u0433\u043e\u0440\u0438\u0437\u043e\u043d\u0442\u0430\u043b\u044c\u043d\u043e",
+    "Vertical split": "\u0420\u0430\u0437\u0434\u0435\u043b\u0438\u0442\u044c \u0432\u0435\u0440\u0442\u0438\u043a\u0430\u043b\u044c\u043d\u043e",
     "Insert row above": "\u0412\u0441\u0442\u0430\u0432\u0438\u0442\u044c \u043f\u0443\u0441\u0442\u0443\u044e \u0441\u0442\u0440\u043e\u043a\u0443 \u0441\u0432\u0435\u0440\u0445\u0443",
     "Insert row below": "\u0412\u0441\u0442\u0430\u0432\u0438\u0442\u044c \u043f\u0443\u0441\u0442\u0443\u044e \u0441\u0442\u0440\u043e\u043a\u0443 \u0441\u043d\u0438\u0437\u0443",
     "Delete row": "\u0423\u0434\u0430\u043b\u0438\u0442\u044c \u0441\u0442\u0440\u043e\u043a\u0443",
     "Insert column before": "\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u0441\u0442\u043e\u043b\u0431\u0435\u0446 \u0441\u043b\u0435\u0432\u0430",
     "Insert column after": "\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u0441\u0442\u043e\u043b\u0431\u0435\u0446 \u0441\u043f\u0440\u0430\u0432\u0430",
-    "Delete column": "\u0423\u0434\u0430\u043b\u0438\u0442\u044c \u0441\u0442\u043e\u043b\u0431\u0435\u0446"
+    "Delete column": "\u0423\u0434\u0430\u043b\u0438\u0442\u044c \u0441\u0442\u043e\u043b\u0431\u0435\u0446",
+    "Uploading image": "\u0417\u0430\u0433\u0440\u0443\u0437\u043a\u0430 \u0438\u0437\u043e\u0431\u0440\u0430\u0436\u0435\u043d\u0438\u0439",
+    "Upload File": "\u0417\u0430\u0433\u0440\u0443\u0437\u0438\u0442\u044c \u0444\u0430\u0439\u043b",
+    "Drop File": "\u043f\u0430\u0434\u0435\u043d\u0438\u0435 \u0444\u0430\u0439\u043b\u0430",
+    "Clear formatting": "\u0423\u0434\u0430\u043b\u0438\u0442\u044c \u0444\u043e\u0440\u043c\u0430\u0442\u0438\u0440\u043e\u0432\u0430\u043d\u0438\u0435"
   },
   direction: "ltr"
 };
